==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class NetworkChaosSpecBuilder extends NetworkChaosSpecFluentImpl<NetworkChaosSpecBuilder> implements VisitableBuilder<NetworkChaosSpec,NetworkChaosSpecBuilder>{
  public NetworkChaosSpecBuilder() {
    this(false);
  }
  public NetworkChaosSpecBuilder(Boolean validationEnabled) {
    this(new NetworkChaosSpec(), validationEnabled);
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new NetworkChaosSpec(), validationEnabled);
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,NetworkChaosSpec instance) {
    this(fluent, instance, false);
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,NetworkChaosSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAction(instance.getAction());
      fluent.withBandwidth(instance.getBandwidth());
      fluent.withCorrupt(instance.getCorrupt());
      fluent.withDelay(instance.getDelay());
      fluent.withDevice(instance.getDevice());
      fluent.withDirection(instance.getDirection());
      fluent.withDuplicate(instance.getDuplicate());
      fluent.withDuration(instance.getDuration());
      fluent.withExternalTargets(instance.getExternalTargets());
      fluent.withLoss(instance.getLoss());
      fluent.withMode(instance.getMode());
      fluent.withSelector(instance.getSelector());
      fluent.withTarget(instance.getTarget());
      fluent.withTargetDevice(instance.getTargetDevice());
      fluent.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpec instance) {
    this(instance,false);
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAction(instance.getAction());
      this.withBandwidth(instance.getBandwidth());
      this.withCorrupt(instance.getCorrupt());
      this.withDelay(instance.getDelay());
      this.withDevice(instance.getDevice());
      this.withDirection(instance.getDirection());
      this.withDuplicate(instance.getDuplicate());
      this.withDuration(instance.getDuration());
      this.withExternalTargets(instance.getExternalTargets());
      this.withLoss(instance.getLoss());
      this.withMode(instance.getMode());
      this.withSelector(instance.getSelector());
      this.withTarget(instance.getTarget());
      this.withTargetDevice(instance.getTargetDevice());
      this.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  NetworkChaosSpecFluent<?> fluent;
  Boolean validationEnabled;
  public NetworkChaosSpec build() {
    NetworkChaosSpec buildable = new NetworkChaosSpec(fluent.getAction(),fluent.getBandwidth(),fluent.getCorrupt(),fluent.getDelay(),fluent.getDevice(),fluent.getDirection(),fluent.getDuplicate(),fluent.getDuration(),fluent.getExternalTargets(),fluent.getLoss(),fluent.getMode(),fluent.getSelector(),fluent.getTarget(),fluent.getTargetDevice(),fluent.getValue());
    return buildable;
  }
  
}

==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class NetworkChaosSpecBuilder extends NetworkChaosSpecFluent<NetworkChaosSpecBuilder> implements VisitableBuilder<NetworkChaosSpec,NetworkChaosSpecBuilder>{
  public NetworkChaosSpecBuilder() {
    this(false);
  }
  public NetworkChaosSpecBuilder(Boolean validationEnabled) {
    this(new NetworkChaosSpec(), validationEnabled);
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new NetworkChaosSpec(), validationEnabled);
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,NetworkChaosSpec instance) {
    this(fluent, instance, false);
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpecFluent<?> fluent,NetworkChaosSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new NetworkChaosSpec());

    if (instance != null) {
      fluent.withAction(instance.getAction());
      fluent.withBandwidth(instance.getBandwidth());
      fluent.withCorrupt(instance.getCorrupt());
      fluent.withDelay(instance.getDelay());
      fluent.withDevice(instance.getDevice());
      fluent.withDirection(instance.getDirection());
      fluent.withDuplicate(instance.getDuplicate());
      fluent.withDuration(instance.getDuration());
      fluent.withExternalTargets(instance.getExternalTargets());
      fluent.withLoss(instance.getLoss());
      fluent.withMode(instance.getMode());
      fluent.withSelector(instance.getSelector());
      fluent.withTarget(instance.getTarget());
      fluent.withTargetDevice(instance.getTargetDevice());
      fluent.withValue(instance.getValue());
      fluent.withAction(instance.getAction());
      fluent.withBandwidth(instance.getBandwidth());
      fluent.withCorrupt(instance.getCorrupt());
      fluent.withDelay(instance.getDelay());
      fluent.withDevice(instance.getDevice());
      fluent.withDirection(instance.getDirection());
      fluent.withDuplicate(instance.getDuplicate());
      fluent.withDuration(instance.getDuration());
      fluent.withExternalTargets(instance.getExternalTargets());
      fluent.withLoss(instance.getLoss());
      fluent.withMode(instance.getMode());
      fluent.withSelector(instance.getSelector());
      fluent.withTarget(instance.getTarget());
      fluent.withTargetDevice(instance.getTargetDevice());
      fluent.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpec instance) {
    this(instance,false);
  }
  public NetworkChaosSpecBuilder(NetworkChaosSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new NetworkChaosSpec());

    if (instance != null) {
      this.withAction(instance.getAction());
      this.withBandwidth(instance.getBandwidth());
      this.withCorrupt(instance.getCorrupt());
      this.withDelay(instance.getDelay());
      this.withDevice(instance.getDevice());
      this.withDirection(instance.getDirection());
      this.withDuplicate(instance.getDuplicate());
      this.withDuration(instance.getDuration());
      this.withExternalTargets(instance.getExternalTargets());
      this.withLoss(instance.getLoss());
      this.withMode(instance.getMode());
      this.withSelector(instance.getSelector());
      this.withTarget(instance.getTarget());
      this.withTargetDevice(instance.getTargetDevice());
      this.withValue(instance.getValue());
      this.withAction(instance.getAction());
      this.withBandwidth(instance.getBandwidth());
      this.withCorrupt(instance.getCorrupt());
      this.withDelay(instance.getDelay());
      this.withDevice(instance.getDevice());
      this.withDirection(instance.getDirection());
      this.withDuplicate(instance.getDuplicate());
      this.withDuration(instance.getDuration());
      this.withExternalTargets(instance.getExternalTargets());
      this.withLoss(instance.getLoss());
      this.withMode(instance.getMode());
      this.withSelector(instance.getSelector());
      this.withTarget(instance.getTarget());
      this.withTargetDevice(instance.getTargetDevice());
      this.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  NetworkChaosSpecFluent<?> fluent;
  Boolean validationEnabled;
  public NetworkChaosSpec build() {
    NetworkChaosSpec buildable = new NetworkChaosSpec(fluent.getAction(),fluent.buildBandwidth(),fluent.buildCorrupt(),fluent.buildDelay(),fluent.getDevice(),fluent.getDirection(),fluent.buildDuplicate(),fluent.getDuration(),fluent.getExternalTargets(),fluent.buildLoss(),fluent.getMode(),fluent.buildSelector(),fluent.buildTarget(),fluent.getTargetDevice(),fluent.getValue());
    return buildable;
  }
  
}
